diff kallithea/model/comment.py @ 4212:24c0d584ba86 kallithea-2.2.5-rebrand

General renaming to Kallithea
author Bradley M. Kuhn <bkuhn@sfconservancy.org>
date Wed, 02 Jul 2014 19:06:01 -0400
parents 1948ede028ef
children 05af189da2ae
line wrap: on
line diff
--- a/kallithea/model/comment.py	Wed Jul 02 19:05:52 2014 -0400
+++ b/kallithea/model/comment.py	Wed Jul 02 19:06:01 2014 -0400
@@ -15,7 +15,7 @@
 kallithea.model.comment
 ~~~~~~~~~~~~~~~~~~~~~~~
 
-comments model for RhodeCode
+comments model for Kallithea
 
 This file was forked by the Kallithea project in July 2014.
 Original author and date, and relevant copyright and licensing information is below:
@@ -97,7 +97,7 @@
                 (user.username, h.short_id(revision))
             # get the current participants of this changeset
             recipients = ChangesetComment.get_users(revision=revision)
             # add changeset author if it's in rhodecode system
             cs_author = User.get_from_cs_author(cs.author)
             if not cs_author:
                 #use repo owner if we cannot extract the author correctly
@@ -97,7 +97,7 @@
             # get the current participants of this changeset
             recipients = ChangesetComment.get_users(revision=revision)
-            # add changeset author if it's in rhodecode system
+            # add changeset author if it's in kallithea system
             cs_author = User.get_from_cs_author(cs.author)
             if not cs_author: